Code coverage report for js/components/BaseComponent.jsx

# All files / js/components BaseComponent.jsx

100% Statements 1/1
100% Branches 0/0
100% Functions 0/0
100% Lines 1/1

    1
    2
    3
    4
    5
    6
    7
    8
    9
    10
    11
    12
    13
    14
    15
    16
    17
    18
    19
    20
    21
    22
    23
    24
    25

    1x

     // the base component.  This really should not exist in the first place
    // but react is a bit meh when it comes to what's on the base component
    // which breaks super.  This is why we do this here.  Note that this is
    // also used by the standalone admin UI app.

    'use strict'

    import React from 'react'

    class BaseComponent extends React.Component {
      componentDidMount () {
      }

      componentWillUnmount () {
      }

      componentDidUpdate () {
      }

      componentWillReceiveProps (nextProps) {
      }
    }

    export default BaseComponent